// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

#if !defined(_ILDASMPCH_H)
#define _ILDASMPCH_H

#define OEMRESOURCE
#define INITGUID

#include <cor.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <limits.h>
#include <conio.h>

#ifndef Debug_ReportError
#define Debug_ReportError(strMessage)
#endif

#endif
